function path_MoRe(b_Add)
    if nargin < 1
        b_Add = true;
    end
    loc_path_more(b_Add);
end

function loc_path_more(b_Add)
    paths = loc_getPaths();
    if b_Add
        addpath(paths{:}, '-end');
        loc_addJarToJavaPathWithClassCheck(mes.more.LismoConfig.LismoJarFullPath, 'com.modelengineers.lismo2_4L.api.Lismo');
        loc_addJarToJavaPath(loc_getMoReJarPath());
        loc_addJarToJavaPath(loc_getEulaDialogJarPath());
        loc_addJarToJavaPath(loc_getMatlabControlJarPath());
    else
        loc_rmJarFromJavaPath(loc_getMatlabControlJarPath());
        loc_rmJarFromJavaPath(loc_getMoReJarPath());
        loc_rmJarFromJavaPath(loc_getEulaDialogJarPath());
        loc_rmJarFromJavaPath(mes.more.LismoConfig.LismoJarFullPath);
        rmpath(paths{:});
    end
end

function paths = loc_getPaths()
    moreBasePath = fileparts(mfilename('fullpath'));
    corePaths = loc_getCorePaths(moreBasePath);
    hookPaths = loc_getHookPaths(moreBasePath);
    libPaths = loc_getLibsPaths(moreBasePath);  
    paths = [moreBasePath, corePaths, hookPaths, libPaths];
end

function corePaths = loc_getCorePaths(moreBasePath)
    corePath = fullfile(moreBasePath, 'core');
    corePaths = genpath(corePath);
end

function hookPaths = loc_getHookPaths(moreBasePath)
    hookPath = fullfile(moreBasePath, 'hooks');
    hookPaths = genpath(hookPath);
end

function libPaths = loc_getLibsPaths(moreBasePath)
    mesUtilsPaths = loc_getMesUtilsPaths(moreBasePath);
    guiLayoutToolboxPaths = loc_getGuiLayoutToolboxPaths(moreBasePath);
    libPaths = [mesUtilsPaths, guiLayoutToolboxPaths];
end

function mesUtilsPaths = loc_getMesUtilsPaths(moreBasePath)
    mesUtilsPaths = {fullfile(moreBasePath, 'libs', 'mesUtils')};
end

function guiLayoutToolboxPaths = loc_getGuiLayoutToolboxPaths(moreBasePath)
    if verLessThan('matlab','7.14') % R2012a
        guiLayoutToolboxPaths = loc_getOldGuiLayoutToolboxPaths(moreBasePath);
    else
        guiLayoutToolboxPaths = loc_getNewGuiLayoutToolboxPaths(moreBasePath);
    end
end

function guiLayoutToolboxPaths = loc_getOldGuiLayoutToolboxPaths(moreBasePath)
    relGuiLayoutToolboxPath = 'libs\GUILayout-v1p10';
    guiLayoutToolboxPath = fullfile(moreBasePath, relGuiLayoutToolboxPath);
    patchPath = fullfile(guiLayoutToolboxPath, 'Patch');
    guiLayoutToolboxPaths = {guiLayoutToolboxPath, patchPath};
end

function guiLayoutToolboxPaths = loc_getNewGuiLayoutToolboxPaths(moreBasePath)
    relGuiLayoutToolboxPath = 'libs\GUI Layout Toolbox 2.1.2\layout';
    guiLayoutToolboxPath = fullfile(moreBasePath, relGuiLayoutToolboxPath);
    guiLayoutToolboxPaths = {guiLayoutToolboxPath};
end

function moreJarPath = loc_getMoReJarPath()
    moreBasePath = fileparts(mfilename('fullpath'));
    moreJarPath = fullfile(moreBasePath, 'libs', 'MoRe.jar');
end

function eulaDialogJarPath = loc_getEulaDialogJarPath()
    moreBasePath = fileparts(mfilename('fullpath'));
    eulaDialogJarPath = fullfile(moreBasePath, 'libs', 'EulaDialog.jar');
end

function slMatlabControlJarPath = loc_getMatlabControlJarPath()
    moreBasePath = fileparts(mfilename('fullpath'));
    slMatlabControlJarPath = fullfile(moreBasePath, 'libs', 'matlabcontrol-4.1.0.jar');
end

function loc_addJarToJavaPathWithClassCheck(fullPathOfJar, classToCheck)
    if ~exist(classToCheck, 'class')
        javaaddpath(fullPathOfJar);
    end
end

function loc_addJarToJavaPath(fullPathOfJar)
    classpath = javaclasspath('-all');
    [~, jarFileName, jarEnding] = fileparts(fullPathOfJar);
    jarFileNameWithEnding = [jarFileName, jarEnding];
    jarAlreadyInClassPath = any(mes.more_mes.ml.string.contains(classpath, jarFileNameWithEnding));
    if ~jarAlreadyInClassPath
       javaaddpath(fullPathOfJar);
   end
end

function loc_rmJarFromJavaPath(fullPathOfJar)
    classpath = javaclasspath('-all');
    if ismember(fullPathOfJar, classpath)
        javarmpath(fullPathOfJar);
    end
end